@@ -1,7 +1,5 @@
 """Handles all operations on varnas"""
 
-import sys
-
 from akshara.varna import Varnamaalaa
 
 vn = Varnamaalaa()
@@ -312,24 +310,25 @@ def get_sankhyaa(roman: str) -> str:
         if digit == ".":
             devanaagari += digit
         elif int(digit) < 0 or int(digit) > 9:
-            print(f"{digit} is Not a digit")
-            sys.exit()
+            raise ValueError(f"Invalid digit {digit} in {roman}")
         else:
             devanaagari += vn.sankhyaa[int(digit)]
 
     return devanaagari
 
 
-def get_akshara(vinyaasa: list) -> list:
+def get_akshara(word: str) -> list:
     """Returns the akshara (syllable) of a string
 
     Args:
-        vinyaasa (list): Vinyaasa of the string
+        word (str): String to be syllabified
 
     Returns:
         list: Syllables of the string
     """
 
+    vinyaasa = get_vinyaasa(word)
+
     index_svara = [
         i for i, x in enumerate(vinyaasa) if x in vn.svara or x in vn.anunaasika_svara
     ]
@@ -340,8 +339,6 @@ def get_akshara(vinyaasa: list) -> list:
         akshara.append(get_shabda(vinyaasa[start : i + 1]))
         start = i + 1
 
-    print(index_svara)
-
     if index_svara and index_svara[-1] != len(vinyaasa) - 1:
 
         if len(akshara) == 1:
